@@ -4,19 +4,12 @@ from jobsworthy import repo
 
 class PerformanceMetric(repo.HiveRepo):
     table_name = None
-
-    def emit_metrics(self, perf_data):
-        return self.create(self.create_df(data=perf_data))
-
-    def schema(self):
-        """
-        The default schema for the table
-        :return:
-        """
-        return T.StructType([
+    schema = T.StructType([
             T.StructField("run", T.StringType(), True),
             T.StructField("time", T.StringType(), True),
             T.StructField("counter", T.IntegerType(), True),
             T.StructField("perfMetrics", T.MapType(T.StringType(), T.ArrayType(T.FloatType(), True)), True)
         ])
 
+    def emit_metrics(self, perf_data):
+        return self.write_append(self.create_df(data=perf_data))
