@@ -24,9 +24,9 @@ messages = {
     'checkpoint_root_not_supported': """Jobsworthy: use of checkpoint_root not supported since version 0.4.0.  
     Use db_path_override_for_checkpoint instead.""",
 
-    'checkpoint_override_must_be_supported_in_test': """Configuration of db_path_override_for_checkpoint must be 
-    provided when in testing and when using delta table operations.  To disable this exception remove the call to 
-    running_in_test() from the JobConfig.""",
+    'delta_location_configured_incorrectly': """The Delta Location is configured incorrectly.  This is probably due to 
+    db_path_override_for_checkpoint missing when in testing.  Either fix the config or disable the check by 
+    removing the call to running_in_test() from the JobConfig.""",
 
     "db_path_not_configured": """Jobsworth: db path not configured.  Set db_file_system_path_root on the HIVE config""",
 
@@ -68,8 +68,8 @@ def no_schema_provided_on_create_df():
     return error.RepoWriteError(messages[no_schema_provided_on_create_df.__name__])
 
 
-def checkpoint_override_must_be_supported_in_test():
-    return error.RepoConfigError(messages[checkpoint_override_must_be_supported_in_test.__name__])
+def delta_location_configured_incorrectly():
+    return error.RepoConfigError(messages[delta_location_configured_incorrectly.__name__])
 
 def db_path_not_configured():
     return error.RepoConfigError(messages[db_path_not_configured.__name__])
